#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class MailTips:
    def __init__(self):
        self.forRecipient = None
        self.matchingTips = None
        pass


class __MailTipsSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MailTips()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.mailflow.common.api.Recipient import Recipient
        from netbluemind.mailflow.common.api.Recipient import __RecipientSerDer__
        forRecipientValue = value['forRecipient']
        instance.forRecipient = __RecipientSerDer__().parse(forRecipientValue)
        from netbluemind.mailmessage.api.MailTip import MailTip
        from netbluemind.mailmessage.api.MailTip import __MailTipSerDer__
        matchingTipsValue = value['matchingTips']
        instance.matchingTips = serder.ListSerDer(
            __MailTipSerDer__()).parse(matchingTipsValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.mailflow.common.api.Recipient import Recipient
        from netbluemind.mailflow.common.api.Recipient import __RecipientSerDer__
        forRecipientValue = value.forRecipient
        instance["forRecipient"] = __RecipientSerDer__().encode(
            forRecipientValue)
        from netbluemind.mailmessage.api.MailTip import MailTip
        from netbluemind.mailmessage.api.MailTip import __MailTipSerDer__
        matchingTipsValue = value.matchingTips
        instance["matchingTips"] = serder.ListSerDer(
            __MailTipSerDer__()).encode(matchingTipsValue)
        return instance
