#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class SchemaCheckInfo:
    def __init__(self):
        self.server = None
        self.db = None
        self.statements = None
        pass


class __SchemaCheckInfoSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = SchemaCheckInfo()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        serverValue = value['server']
        instance.server = serder.STRING.parse(serverValue)
        dbValue = value['db']
        instance.db = serder.STRING.parse(dbValue)
        statementsValue = value['statements']
        instance.statements = serder.STRING.parse(statementsValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        serverValue = value.server
        instance["server"] = serder.STRING.encode(serverValue)
        dbValue = value.db
        instance["db"] = serder.STRING.encode(dbValue)
        statementsValue = value.statements
        instance["statements"] = serder.STRING.encode(statementsValue)
        return instance
